package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppDealScale;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

/**
 * 主播分成比例Mapper接口
 *
 * @author game
 * @date 2024-08-11
 */
public interface AppDealScaleMapper extends BaseMapper<AppDealScale> {
    /**
     * 查询主播分成比例
     *
     * @param id 主播分成比例主键
     * @return 主播分成比例
     */
    public AppDealScale selectAppDealScaleById(Long id);

    /**
     * 查询主播分成比例列表
     *
     * @param appDealScale 主播分成比例
     * @return 主播分成比例集合
     */
    public List<AppDealScale> selectAppDealScaleList(AppDealScale appDealScale);

    /**
     * 新增主播分成比例
     *
     * @param appDealScale 主播分成比例
     * @return 结果
     */
    public int insertAppDealScale(AppDealScale appDealScale);

    /**
     * 修改主播分成比例
     *
     * @param appDealScale 主播分成比例
     * @return 结果
     */
    public int updateAppDealScale(AppDealScale appDealScale);

    /**
     * 删除主播分成比例
     *
     * @param id 主播分成比例主键
     * @return 结果
     */
    public int deleteAppDealScaleById(Long id);

    /**
     * 批量删除主播分成比例
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppDealScaleByIds(Long[] ids);

    @Update("update sys_sequence set next_val = next_val + 1 where sequence_name = 'app_deal_scale'")
    public int updateId();

    @Select("select next_val from sys_sequence where sequence_name = 'app_deal_scale'")
    public Long getNextId();
}